@@ -51,7 +51,7 @@ initial_tab_new (const char *profile,
 	it->zoom = 1.0;
 	it->zoom_set = FALSE;
 	it->active = FALSE;
-    it->attach_window = FALSE;
+	it->attach_window = FALSE;
 
 	return it;
 }
@@ -306,8 +306,8 @@ option_tab_callback (const gchar *option_name,
 {
 	TerminalOptions *options = data;
 	gboolean is_profile_id;
-    InitialWindow *iw;
-    InitialTab *it;    
+	InitialWindow *iw;
+	InitialTab *it;
 
 	is_profile_id = g_str_has_suffix (option_name, "-with-profile-internal-id");
 
@@ -317,11 +317,11 @@ option_tab_callback (const gchar *option_name,
 		iw->tabs = g_list_append (iw->tabs, initial_tab_new (value, is_profile_id));
 	}
 	else
-    {
-        iw = add_new_window (options, value, is_profile_id);
-        it = g_list_last(iw->tabs)->data;
-        it->attach_window = TRUE;
-    }
+	{
+		iw = add_new_window (options, value, is_profile_id);
+		it = g_list_last(iw->tabs)->data;
+		it->attach_window = TRUE;
+	}
 
 	return TRUE;
 }
@@ -712,7 +712,7 @@ terminal_options_parse (const char *working_directory,
 	options->default_maximize = FALSE;
 	options->execute = FALSE;
 	options->use_factory = TRUE;
-    options->initial_workspace = -1;
+	options->initial_workspace = -1;
 
 	options->env = g_strdupv (env);
 	options->startup_id = g_strdup (startup_id && startup_id[0] ? startup_id : NULL);
@@ -723,7 +723,6 @@ terminal_options_parse (const char *working_directory,
 	options->default_title = NULL;
 	options->zoom = 1.0;
 
-	options->screen_number = -1;
 	options->default_working_dir = g_strdup (working_directory);
 
 	/* The old -x/--execute option is broken, so we need to pre-scan for it. */
