@@ -76,10 +76,10 @@ enum
     PROP_SILENT_BELL,
     PROP_TITLE,
     PROP_TITLE_MODE,
-    PROP_UPDATE_RECORDS,
     PROP_USE_CUSTOM_COMMAND,
     PROP_USE_CUSTOM_DEFAULT_SIZE,
     PROP_USE_SKEY,
+    PROP_USE_URLS,
     PROP_USE_SYSTEM_FONT,
     PROP_USE_THEME_COLORS,
     PROP_VISIBLE_NAME,
@@ -118,10 +118,10 @@ enum
 #define KEY_COPY_SELECTION "copy-selection"
 #define KEY_TITLE_MODE "title-mode"
 #define KEY_TITLE "title"
-#define KEY_UPDATE_RECORDS "update-records"
 #define KEY_USE_CUSTOM_COMMAND "use-custom-command"
 #define KEY_USE_CUSTOM_DEFAULT_SIZE "use-custom-default-size"
 #define KEY_USE_SKEY "use-skey"
+#define KEY_USE_URLS "use-urls"
 #define KEY_USE_SYSTEM_FONT "use-system-font"
 #define KEY_USE_THEME_COLORS "use-theme-colors"
 #define KEY_VISIBLE_NAME "visible-name"
@@ -159,10 +159,10 @@ enum
 #define DEFAULT_COPY_SELECTION        (FALSE)
 #define DEFAULT_TITLE_MODE            (TERMINAL_TITLE_REPLACE)
 #define DEFAULT_TITLE                 (N_("Terminal"))
-#define DEFAULT_UPDATE_RECORDS        (TRUE)
 #define DEFAULT_USE_CUSTOM_COMMAND    (FALSE)
 #define DEFAULT_USE_CUSTOM_DEFAULT_SIZE (FALSE)
 #define DEFAULT_USE_SKEY              (TRUE)
+#define DEFAULT_USE_URLS              (TRUE)
 #define DEFAULT_USE_SYSTEM_FONT       (TRUE)
 #define DEFAULT_USE_THEME_COLORS      (TRUE)
 #define DEFAULT_VISIBLE_NAME          (N_("Unnamed"))
@@ -308,7 +308,7 @@ static void ensure_pixbuf_property (TerminalProfile *profile,
 static guint signals[LAST_SIGNAL] = { 0 };
 static GQuark gsettings_key_quark;
 
-G_DEFINE_TYPE (TerminalProfile, terminal_profile, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (TerminalProfile, terminal_profile, G_TYPE_OBJECT);
 
 /* gdk_rgba_equal is too strict! */
 static gboolean
@@ -849,10 +849,12 @@ terminal_profile_save (TerminalProfile *profile)
 	TerminalProfilePrivate *priv = profile->priv;
 	GSettings *changeset;
 	GSList *l;
+	gchar *concat;
 
 	priv->save_idle_id = 0;
-	changeset = g_settings_new_with_path (CONF_PROFILE_SCHEMA,
-					      g_strconcat (CONF_PROFILE_PREFIX, priv->profile_dir,"/", NULL));
+	concat = g_strconcat (CONF_PROFILE_PREFIX, priv->profile_dir,"/", NULL);
+	changeset = g_settings_new_with_path (CONF_PROFILE_SCHEMA, concat);
+	g_free (concat);
 	g_settings_delay (changeset);
 
 	for (l = priv->dirty_pspecs; l != NULL; l = l->next)
@@ -909,7 +911,7 @@ terminal_profile_init (TerminalProfile *profile)
 	GParamSpec **pspecs;
 	guint n_pspecs, i;
 
-	priv = profile->priv = G_TYPE_INSTANCE_GET_PRIVATE (profile, TERMINAL_TYPE_PROFILE, TerminalProfilePrivate);
+	priv = profile->priv = terminal_profile_get_instance_private (profile);
 
 	priv->gsettings_notification_pspec = NULL;
 	priv->locked = g_new0 (gboolean, LAST_PROP);
@@ -955,6 +957,7 @@ terminal_profile_constructor (GType type,
 	const char *name;
 	GParamSpec **pspecs;
 	guint n_pspecs, i;
+	gchar *concat;
 
 	object = G_OBJECT_CLASS (terminal_profile_parent_class)->constructor
 	         (type, n_construct_properties, construct_params);
@@ -965,14 +968,18 @@ terminal_profile_constructor (GType type,
 	name = g_value_get_string (g_value_array_get_nth (priv->properties, PROP_NAME));
 	g_assert (name != NULL);
 
-	priv->settings = g_settings_new_with_path (CONF_PROFILE_SCHEMA,
-		g_strconcat (CONF_PROFILE_PREFIX, name, "/", NULL));
+	concat = g_strconcat (CONF_PROFILE_PREFIX, name, "/", NULL);
+	priv->settings = g_settings_new_with_path (CONF_PROFILE_SCHEMA, concat);
 	g_assert (priv->settings != NULL);
+	g_free (concat);
+	concat = g_strconcat("changed::", priv->profile_dir, "/", NULL);
 	g_signal_connect (priv->settings,
-			  g_strconcat("changed::", priv->profile_dir, "/", NULL),
+			  concat,
 			  G_CALLBACK(terminal_profile_gsettings_notify_cb),
 			  profile);
 
+	g_free (concat);
+
 	/* Now load those properties from GSettings that were not set as construction params */
 	pspecs = g_object_class_list_properties (G_OBJECT_CLASS (TERMINAL_PROFILE_GET_CLASS (profile)), &n_pspecs);
 	for (i = 0; i < n_pspecs; ++i)
@@ -1123,16 +1130,20 @@ terminal_profile_set_property (GObject *object,
 		g_assert (name != NULL);
 		priv->profile_dir = g_strdup (name);
 		if (priv->settings != NULL) {
+			gchar *concat;
 			g_signal_handlers_disconnect_by_func (priv->settings,
 							      G_CALLBACK(terminal_profile_gsettings_notify_cb),
 							      profile);
 			g_object_unref (priv->settings);
-			priv->settings = g_settings_new_with_path (CONF_PROFILE_SCHEMA,
-						g_strconcat (CONF_PROFILE_PREFIX, priv->profile_dir, "/", NULL));
+			concat=  g_strconcat (CONF_PROFILE_PREFIX, priv->profile_dir, "/", NULL);
+			priv->settings = g_settings_new_with_path (CONF_PROFILE_SCHEMA, concat);
+			g_free (concat);
+			concat = g_strconcat("changed::", priv->profile_dir, "/", NULL);
 			g_signal_connect (priv->settings,
-					  g_strconcat("changed::", priv->profile_dir, "/", NULL),
-						      G_CALLBACK(terminal_profile_gsettings_notify_cb),
+					  concat,
+					  G_CALLBACK(terminal_profile_gsettings_notify_cb),
 					  profile);
+			g_free (concat);
 		}
 		break;
 	}
@@ -1177,8 +1188,6 @@ terminal_profile_class_init (TerminalProfileClass *klass)
 
 	gsettings_key_quark = g_quark_from_static_string ("GT::GSettingsKey");
 
-	g_type_class_add_private (object_class, sizeof (TerminalProfilePrivate));
-
 	object_class->constructor = terminal_profile_constructor;
 	object_class->finalize = terminal_profile_finalize;
 	object_class->get_property = terminal_profile_get_property;
@@ -1287,10 +1296,10 @@ terminal_profile_class_init (TerminalProfileClass *klass)
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (SCROLL_ON_OUTPUT, DEFAULT_SCROLL_ON_OUTPUT, KEY_SCROLL_ON_OUTPUT);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (SILENT_BELL, DEFAULT_SILENT_BELL, KEY_SILENT_BELL);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (COPY_SELECTION, DEFAULT_COPY_SELECTION, KEY_COPY_SELECTION);
-	TERMINAL_PROFILE_PROPERTY_BOOLEAN (UPDATE_RECORDS, DEFAULT_UPDATE_RECORDS, KEY_UPDATE_RECORDS);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (USE_CUSTOM_COMMAND, DEFAULT_USE_CUSTOM_COMMAND, KEY_USE_CUSTOM_COMMAND);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (USE_CUSTOM_DEFAULT_SIZE, DEFAULT_USE_CUSTOM_DEFAULT_SIZE, KEY_USE_CUSTOM_DEFAULT_SIZE);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (USE_SKEY, DEFAULT_USE_SKEY, KEY_USE_SKEY);
+	TERMINAL_PROFILE_PROPERTY_BOOLEAN (USE_URLS, DEFAULT_USE_URLS, KEY_USE_URLS);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (USE_SYSTEM_FONT, DEFAULT_USE_SYSTEM_FONT, KEY_USE_SYSTEM_FONT);
 	TERMINAL_PROFILE_PROPERTY_BOOLEAN (USE_THEME_COLORS, DEFAULT_USE_THEME_COLORS, KEY_USE_THEME_COLORS);
 
